pilas.habilidades

Package pilas :: Module habilidades |
[hide private]
[frames] | no frames]

# Module habilidades

source code

Classes | [hide private]
| Habilidad Representa una habilidad que un actor puede aprender.
| RebotarComoPelota Le indica al actor que rebote y colisiones como una pelota.
| RebotarComoCaja Le indica al actor que rebote y colisiones como una caja cuadrada.
| ColisionableComoPelota Le indica al actor que colisione como una pelota, pero que no rebote.
| SeguirAlMouse Hace que un actor siga la posición del mouse en todo momento.
| RotarConMouse "Hace que un actor rote con respecto a la posicion del mouse.
| MirarAlActor "Hace que un actor rote para mirar hacia otro actor.
| AumentarConRueda Permite cambiar el tamaño de un actor usando la ruedita scroll del mouse.
| SeguirClicks Hace que el actor se coloque la posición del cursor cuando se hace click.
| Arrastrable Hace que un objeto se pueda arrastrar con el puntero del mouse.
| MoverseConElTeclado Hace que un actor cambie de posición con pulsar el teclado.
| MoverseComoCoche Hace que un actor se mueva como un coche.
| PuedeExplotar Hace que un actor se pueda hacer explotar invocando al metodo eliminar.
| SiempreEnElCentro Hace que un actor siempre esté en el centro de la camara y la desplace cuando el actor se desplaza.
| SeMantieneEnPantalla Se asegura de que el actor regrese a la pantalla si sale o que no salga en nigún momento de la pantalla.
| PisaPlataformas Enseña al actor a pisar plataformas físicas.
| Imitar Logra que el actor imite las propiedades de otro.
| Disparar Establece la habilidad de poder disparar un Actor o un objeto de tipo pilas.municion.Municion.
| DispararConClick Establece la habilidad de poder disparar un Actor o un objeto de tipo pilas.municion.Municion pulsando el boton izquierdo del ratón.

Variables | [hide private]
| __package__ = ``'``pilas``'``